Cell

Struct Cell 

pub struct Cell<D, Ix = DefaultIx>
where Ix: IndexType,
{ pub data: Option<Box<D>>, /* private fields */ }
A Cell is an entry point for data within the graph structure. It is formed by surrounding super::Edges and represents area data.

Fields

data: Option<Box<D>>

The assosiated data attached to this Cell.

Implementations

Source

impl<D, Ix> Cell<D, Ix>
where Ix: IndexType,

pub fn new(edges: Vec<EdgeIndex<Ix>>, data: Option<Box<D>>) -> Self

Produces a new Cell with the given edges and (optional) data.

pub fn edges(&self) -> Vec<EdgeIndex<Ix>>

Returns a vec of assosiated edge indicies.